@@ -31,6 +31,10 @@
 
 (require 'texinfo)
 
+;; Silence the compiler for Emacs compiled `--with-native-compilation':
+(declare-function TeX-TeX-sentinel "tex-buf"
+                  (process name))
+
 ;;; Environments:
 (defvar Texinfo-environment-list
   '(("cartouche") ("command") ("copying") ("defcv") ("deffn") ("defivar")
@@ -193,7 +197,7 @@ structuring commands matched by regexp in variable
 of variable `texinfo-section-list'.
 
 If optional argument NO-SUBSECTION is set to any integer or is a
-non nil empty argument (i.e. `C-u \\[Texinfo-mark-section]'),
+non nil empty argument (that is, `\\[universal-argument] \\[Texinfo-mark-section]'),
 then mark the current section with exclusion of any subsections.
 
 Otherwise, any included subsections are also marked along with
@@ -269,7 +273,7 @@ the section."
       (TeX-activate-region) )))
 
 (defun Texinfo-mark-node ()
-  "Mark the current node.  \
+  "Mark the current node.
 This is the node in which the pointer is.  It is starting at
 previous beginning of keyword `@node' and ending at next
 beginning of keyword `@node' or `@bye'."
@@ -293,7 +297,8 @@ beginning of keyword `@node' or `@bye'."
 character. Return the resulting string."
   (let ((pos 0) (map '(("comma" . ","))))
     (while (and (< pos (length
-                        node-name)) (string-match "@\\(comma\\)[[:blank:]]*{}" node-name pos))
+                        node-name))
+                (string-match "@\\(comma\\)[[:blank:]]*{}" node-name pos))
       (setq node-name (concat  (substring node-name 0 (match-beginning 0))
                                (cdr (assoc-string (match-string 1 node-name) map))
                                (substring node-name (match-end 0)))
@@ -412,7 +417,8 @@ each invocation."
     (insert " " l " @| " c " @| " r)))
 
 (defun Texinfo-arg-next-line (_optional &rest _args)
-  "Go to the beginning of next line if we are at the end of line. Otherwise insert an end-of-line."
+  "Go to the beginning of next line if we are at the end of line.
+Otherwise insert an end-of-line."
   (if (eolp)  (forward-line) (insert "\n")))
 
 (defun Texinfo-arg-on|off (optional &optional prompt style)
@@ -474,8 +480,10 @@ is assumed by default."
            (if (nth 1 reftex-label-menu-flags) ; section number flag
                (concat section-number " "))
            text))
-    (list 'toc "toc" text file marker level section-number
-          literal (marker-position marker))))
+    (prog1
+        (list 'toc "toc" text file marker level section-number
+              literal (marker-position marker))
+      (set-marker marker nil))))
 
 (defun Texinfo-reftex-hook ()
   "Hook function to plug Texinfo into RefTeX."
@@ -635,7 +643,7 @@ is assumed by default."
 Special commands:
 \\{Texinfo-mode-map}
 
-Entering Texinfo mode calls the value of `text-mode-hook'  and then the
+Entering Texinfo mode calls the value of `text-mode-hook' and then the
 value of `Texinfo-mode-hook'."
   (interactive)
   (kill-all-local-variables)
@@ -656,13 +664,14 @@ value of `Texinfo-mode-hook'."
   (set (make-local-variable 'require-final-newline) t)
   (set (make-local-variable 'indent-tabs-mode) nil)
   (set (make-local-variable 'paragraph-separate)
-       (concat "\b\\|@[a-zA-Z]*[ \n]\\|" paragraph-separate))
+       (concat "@[a-zA-Z]*[ \n]\\|" paragraph-separate))
   (set (make-local-variable 'paragraph-start)
-       (concat "\b\\|@[a-zA-Z]*[ \n]\\|" paragraph-start))
+       (concat "@[a-zA-Z]*[ \n]\\|" paragraph-start))
   (set (make-local-variable 'fill-column) 72)
   (set (make-local-variable 'comment-start) "@c ")
   (set (make-local-variable 'comment-start-skip) "@c +\\|@comment +")
   (set (make-local-variable 'comment-use-syntax) nil)
+  (setq TeX-comment-start-regexp "@c\\(?:omment\\)?\\>")
   (set (make-local-variable 'words-include-escapes) t)
   (set (make-local-variable 'imenu-generic-expression)
        texinfo-imenu-generic-expression)
@@ -861,10 +870,11 @@ value of `Texinfo-mode-hook'."
   (run-mode-hooks 'text-mode-hook 'Texinfo-mode-hook)
   (TeX-set-mode-name))
 
-(defcustom Texinfo-clean-intermediate-suffixes nil
+(defcustom Texinfo-clean-intermediate-suffixes
+  '("\\.cps?" "\\.vrs?" "\\.fns?" "\\.tps?" "\\.pgs?" "\\.kys?")
   "List of regexps matching suffixes of files to be deleted.
 The regexps will be anchored at the end of the file name to be matched,
-i.e. you do _not_ have to cater for this yourself by adding \\\\' or $."
+that is, you do _not_ have to cater for this yourself by adding \\\\' or $."
   :type '(repeat regexp)
   :group 'TeX-command)
 
@@ -874,7 +884,7 @@ i.e. you do _not_ have to cater for this yourself by adding \\\\' or $."
     "_toc\\.html" "_fot\\.html" "_abt\\.html" "_[0-9]+\\.html" "_l2h_img.+")
   "List of regexps matching suffixes of files to be deleted.
 The regexps will be anchored at the end of the file name to be matched,
-i.e. you do _not_ have to cater for this yourself by adding \\\\' or $."
+that is, you do _not_ have to cater for this yourself by adding \\\\' or $."
   :type '(repeat regexp)
   :group 'TeX-command)
 
